@@ -1,6 +1,8 @@
 import os,pathlib
-fontPath = os.path.join(pathlib.Path(__file__).parent.absolute(),'fonts/')
+from pkg_resources import resource_string
+fontPath = resource_string(__name__, 'fonts/')
 castoro = os.path.join(fontPath,'castoro/Castoro-Regular.ttf')
 texturina = os.path.join(fontPath,'texturina/Texturina-Regular-opsz=24.ttf')
 inconsolata = os.path.join(fontPath,'inconsolata/static/Inconsolata-Black.ttf')
 nova = os.path.join(fontPath,'nova/NovaMono-Regular.ttf')
+print(nova)
